#!/usr/bin/perl
# this script checks whether the installed g++ supports precompiling header files
$res = "";
$os = `uname -s`;
if( $ARGV[0] =~ /g\+\+/ ) {
    $version = `$ARGV[0] --version`;
#     remove comments in parentheses, they may or may not contain spaces
    $version =~ s/\(.*?\)//g;
#     at this point $version should look like "g++  x.y.z ...."
    @v1 = split( /\s+/, $version );
    @v2 = split( /\./, $v1[1] );
#     $v2[0] is major revision, $v2[1] is minor revision, $v2[2] is microversion
#     precompiling headers is supported from g++ 3.4.0 onwards
#     it's broken on FreeBSD 11.0-RELEASE, so disable it on all BSD variants to be safe
    if( $os !~ /bsd/i && (( $v2[0] == 3 && $v2[1] >= 4 ) || $v2[0] >= 4) ) {
	$res .= "precompile ";
    }
#     on modern FreeBSD installations, LLVM is the standard compiler
#     if you use GNU g++, you need different runtime support libraries
    if( $os =~ /FreeBSD/ ) {
	$libdir = "/usr/local/lib/gcc";
	if( $v2[0] <= 4 ) {
	    $libdir .= "$v2[0]$v2[1]";
	}
	else {
	    $libdir .= "$v2[0]";
	}
	if( -d $libdir ) {
	    $res .= "rpath=$libdir ";
	}
    }
#     vectorization is supported from g++ 4.0.0 onwards
    if( $v2[0] >= 4 ) {
	$res .= "vectorize ";
    }
}
# remove trailing spaces
$res =~ s/ +$//;
if( $res ne "" ) {
    print "$res\n";
}
